@@ -18,6 +18,7 @@
 -- See: https://github.com/dbt-labs/dbt-core/blob/13b18654f/plugins/postgres/dbt/include/postgres/macros/adapters.sql
 
 {% macro materialize__create_view_as(relation, sql) -%}
+
   create view {{ relation }}
   as (
     {{ sql }}
@@ -25,7 +26,12 @@
 {%- endmacro %}
 
 {% macro materialize__create_materialized_view_as(relation, sql) -%}
+  {%- set cluster = config.get('cluster', target.cluster) -%}
+
   create materialized view {{ relation }}
+  {% if cluster %}
+    in cluster {{ cluster }}
+  {% endif %}
   as (
     {{ sql }}
   );
@@ -64,26 +70,37 @@
 
 {% macro materialize__get_create_index_sql(relation, index_dict) -%}
   {%- set index_config = adapter.parse_index(index_dict) -%}
-  {%- set comma_separated_columns = ", ".join(index_config.columns) -%}
-  {%- set index_name = index_config.render(relation) -%}
-    create index if not exists
-      "{{ index_name }}"
-      on {{ relation }} {% if index_config.type -%}
-        using {{ index_config.type }}
-  {%- endif %}
-  ({{ comma_separated_columns }});
+  {%- set cluster = index_config.cluster or config.get('cluster', target.cluster) -%}
+    create
+    {% if index_config.default -%}
+      default
+    {%- endif %}
+    index
+    {% if index_config.name -%}
+      "{{ index_config.name }}"
+    {%- endif %}
+    {% if cluster -%}
+      in cluster {{ cluster }}
+    {%- endif %}
+    on {{ relation }}
+    {% if index_config.columns -%}
+      ({{ ", ".join(index_config.columns) }})
+    {%- endif %};
 {%- endmacro %}
 
+
+-- In the dbt-adapter we extend the Relation class to include sinks and indexes
 {% macro materialize__list_relations_without_caching(schema_relation) %}
   {% call statement('list_relations_without_caching', fetch_result=True) -%}
     select
         d.name as database,
         s.name as schema,
         o.name,
-        case when o.type = 'materialized view' then 'materializedview' else o.type end as type
+        case when o.type = 'materialized-view' then 'materializedview' else o.type end as type
     from mz_objects o
     join mz_schemas s on o.schema_id = s.id and s.name = '{{ schema_relation.schema }}'
     join mz_databases d on s.database_id = d.id and d.name = '{{ schema_relation.database }}'
+    where type in ('table', 'source', 'view', 'materialized-view', 'index', 'sink')
   {% endcall %}
   {{ return(load_result('list_relations_without_caching').table) }}
 {% endmacro %}
